### must be used with data files provided

######################################################
#                 DATA AND LIBRARIES                 #
######################################################

# importing data
raw_data=read.table("data.txt", h=T, na.strings=c("na", "NA", "pending"))
dam_data=read.table("dam_data.txt", h=T, na.strings=c("na", "NA"))
data=raw_data

# creating data for herbivory analyses
dam_data$af_area=round(dam_data$af_area*100)
dam_data$be_area=round(dam_data$be_area*100)
dam_data$af_dam_raw=round(dam_data$af_dam_raw*100)
dam_data$be_dam_raw=round(dam_data$be_dam_raw*100)
dam_data$af_dam=dam_data$af_dam_raw/dam_data$af_area
dam_data$be_dam=dam_data$be_dam_raw/dam_data$be_area
dam_data=merge(dam_data,data,by="number")

# loading libraries
library(AER)
library(ordinal)
library(VGAM)

######################################################
#        CORRELATION BETWEEN FORAGING AND PKG        #
######################################################

# within the whole dataset
temp_data=subset(data)
cor.test(temp_data$FoldChg_For,temp_data$FoldChg_PKG,method="spearman")

# including only controls
temp_data=subset(data, data$treatment=="ctrl")
cor.test(temp_data$FoldChg_For,temp_data$FoldChg_PKG,method="spearman")

######################################################
#  EFFECT OF TREATMENT ON FORAGING EXPRESSION LEVEL  #
######################################################

# model
lm1 = glm(FoldChg_For~domat*treatment,data=subset(data), family=quasipoisson)

# fit tests
layout(matrix(1:4,ncol=2)); plot(lm1); shapiro.test(residuals(lm1)); bptest(lm1); dwtest(lm1)

# effects
summary(lm1)
Anova(lm1, contrasts=list(topic=contr.sum, sys=contr.sum), type=3)

######################################################
#    EFFECT OF TREATMENT ON PKG EXPRESSION LEVEL     #
######################################################

# model
lm1 = glm(FoldChg_PKG~domat*treatment,data=subset(data, rownames(data)!=48),family=quasipoisson)

# fit tests
layout(matrix(1:4,ncol=2)); plot(lm1); shapiro.test(residuals(lm1)); bptest(lm1); dwtest(lm1)

# effects
summary(lm1)
Anova(lm1, contrasts=list(topic=contr.sum, sys=contr.sum), type=3)

######################################################
#    EFFECT OF TREATMENT ON GRASSHOPPER DISCOVERY    #
######################################################

# model
lm1 = glm(a_sum>0~ treatment*b_sum,data=subset(data),family=binomial)

# model simplification
lm2 = glm(a_sum>0~ treatment+b_sum,data=subset(data),family=binomial)
BIC(lm1); BIC(lm2)

# effects
summary(lm1)
Anova(lm1, contrasts=list(topic=contr.sum, sys=contr.sum), type=3)

######################################################
#      EFFECT OF TREATMENT ON BODYGUARD NUMBER       #
######################################################

# model
lm1 = glm(a_mean~ treatment*b_mean,data=subset(data), family=poisson)

# fit tests
dispersiontest(lm1,trafo=1)
lm2 = glm(a_mean~ treatment*b_mean,data=subset(data), family=quasipoisson)
layout(matrix(1:4,ncol=2)); plot(lm2); shapiro.test(residuals(lm2)); bptest(lm2); dwtest(lm2)

# effects
Anova(lm2, contrasts=list(topic=contr.sum, sys=contr.sum), type=3)
summary(lm2)


######################################################
#          EFFECT OF TREATMENT ON HERBIVORY          #
######################################################

# preparing data
temp_data=subset(dam_data, is.na(af_dam)==F)
temp_data$ratio_dam_cat=with(temp_data, (af_dam_raw-be_dam_raw)/af_area)
temp_data$ratio_dam_cat=replace(temp_data$ratio_dam_cat, temp_data$ratio_dam_cat<0.01, 0)
temp_data$ratio_dam_cat=replace(temp_data$ratio_dam_cat, temp_data$ratio_dam_cat>0.1, 2)
temp_data$ratio_dam_cat=replace(temp_data$ratio_dam_cat, temp_data$ratio_dam_cat>0 & temp_data$ratio_dam_cat<0.1, 1)
temp_data$af_area=scale(temp_data$af_area)
summary(as.factor(temp_data$ratio_dam_cat))

# model
lm1 = clmm(ordered(ratio_dam_cat)~af_area*treatment+(1|number), data=temp_data, threshold = "flexible")

# effects
summary(lm1)
drop1(lm1,scope=~af_area*treatment,test="Chi")

######################################################
# EFFECT OF GENE EXPRESSION ON GRASSHOPPER DISCOVERY #
######################################################

# model
lm1 = glm(a_sum>0~ FoldChg_For*FoldChg_PKG,data=subset(data, data$treatment=="ctrl"),family=binomial)

# effects
Anova(lm1, contrasts=list(topic=contr.sum, sys=contr.sum), type=3)
summary(lm1)

######################################################
#   EFFECT OF GENE EXPRESSION ON BODYGUARD NUMBER    #
######################################################

# model
lm1 = glm(a_mean~ FoldChg_For*FoldChg_PKG,data=subset(data, data$treatment=="ctrl" & is.na(data$FoldChg_For)==F), family=poisson)

# fit tests
dispersiontest(lm1,trafo=1)
lm2 = glm(a_mean~ FoldChg_For*FoldChg_PKG,data=subset(data, data$treatment=="ctrl" & is.na(data$FoldChg_For)==F), family=quasipoisson)
layout(matrix(1:4,ncol=2)); plot(lm2); shapiro.test(residuals(lm2)); bptest(lm2); dwtest(lm2)

# effects
Anova(lm2, contrasts=list(topic=contr.sum, sys=contr.sum), type=3)
summary(lm2)

######################################################
#       EFFECT OF GENE EXPRESSION ON HERBIVORY       #
######################################################

# preparing data
temp_data=subset(dam_data, dam_data$treatment=="ctrl" & is.na(af_dam)==F)
temp_data$ratio_dam_cat=with(temp_data, (af_dam_raw-be_dam_raw)/af_area)
temp_data$ratio_dam_cat=replace(temp_data$ratio_dam_cat, temp_data$ratio_dam_cat<0.01, 0)
temp_data$ratio_dam_cat=replace(temp_data$ratio_dam_cat, temp_data$ratio_dam_cat>0.1, 2)
temp_data$ratio_dam_cat=replace(temp_data$ratio_dam_cat, temp_data$ratio_dam_cat>0 & temp_data$ratio_dam_cat<0.1, 1)
temp_data$af_area=scale(temp_data$af_area)
summary(as.factor(temp_data$ratio_dam_cat))

# model
lm1 = clmm(ordered(ratio_dam_cat)~af_area*FoldChg_For*FoldChg_PKG+(1|number), data=temp_data, threshold = "flexible")

#effects
summary(lm1)
drop1(lm1,scope=~af_area*FoldChg_For*FoldChg_PKG,test="Chi")